@@ -6,6 +6,12 @@
  * @package PhpMyAdmin
  */
 
+use PhpMyAdmin\Core;
+use PhpMyAdmin\Gis\GisFactory;
+use PhpMyAdmin\Gis\GisVisualization;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Url;
+
 /**
  * Escapes special characters if the variable is set.
  * Returns an empty string otherwise.
@@ -20,14 +26,15 @@ function escape($variable)
 }
 
 require_once 'libraries/common.inc.php';
-require_once 'libraries/gis/pma_gis_factory.php';
-require_once 'libraries/gis/pma_gis_visualization.php';
-require_once 'libraries/tbl_gis_visualization.lib.php';
+
+if (! isset($_POST['field'])) {
+    PhpMyAdmin\Util::checkParameters(array('field'));
+}
 
 // Get data if any posted
 $gis_data = array();
-if (PMA_isValid($_REQUEST['gis_data'], 'array')) {
-    $gis_data = $_REQUEST['gis_data'];
+if (Core::isValid($_POST['gis_data'], 'array')) {
+    $gis_data = $_POST['gis_data'];
 }
 
 $gis_types = array(
@@ -41,15 +48,17 @@ $gis_types = array(
 );
 
 // Extract type from the initial call and make sure that it's a valid one.
-// Extract from field's values if availbale, if not use the column type passed.
+// Extract from field's values if available, if not use the column type passed.
 if (! isset($gis_data['gis_type'])) {
-    if (isset($_REQUEST['type']) && $_REQUEST['type'] != '') {
-        $gis_data['gis_type'] = strtoupper($_REQUEST['type']);
+    if (isset($_POST['type']) && $_POST['type'] != '') {
+        $gis_data['gis_type'] = mb_strtoupper($_POST['type']);
     }
-    if (isset($_REQUEST['value']) && trim($_REQUEST['value']) != '') {
-        $start = (substr($_REQUEST['value'], 0, 1) == "'") ? 1 : 0;
-        $gis_data['gis_type'] = substr(
-            $_REQUEST['value'], $start, strpos($_REQUEST['value'], "(") - $start
+    if (isset($_POST['value']) && trim($_POST['value']) != '') {
+        $start = (substr($_POST['value'], 0, 1) == "'") ? 1 : 0;
+        $gis_data['gis_type'] = mb_substr(
+            $_POST['value'],
+            $start,
+            mb_strpos($_POST['value'], "(") - $start
         );
     }
     if ((! isset($gis_data['gis_type']))
@@ -58,13 +67,13 @@ if (! isset($gis_data['gis_type'])) {
         $gis_data['gis_type'] = $gis_types[0];
     }
 }
-$geom_type = $gis_data['gis_type'];
+$geom_type = htmlspecialchars($gis_data['gis_type']);
 
 // Generate parameters from value passed.
-$gis_obj = PMA_GIS_Factory::factory($geom_type);
-if (isset($_REQUEST['value'])) {
+$gis_obj = GisFactory::factory($geom_type);
+if (isset($_POST['value'])) {
     $gis_data = array_merge(
-        $gis_data, $gis_obj->generateParams($_REQUEST['value'])
+        $gis_data, $gis_obj->generateParams($_POST['value'])
     );
 }
 
@@ -75,28 +84,28 @@ $wkt = $gis_obj->generateWkt($gis_data, 0);
 $wkt_with_zero = $gis_obj->generateWkt($gis_data, 0, '0');
 $result = "'" . $wkt . "'," . $srid;
 
-// Generate PNG or SVG based visualization
-$format = (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER <= 8)
-    ? 'png' : 'svg';
+// Generate SVG based visualization
 $visualizationSettings = array(
     'width' => 450,
     'height' => 300,
-    'spatialColumn' => 'wkt'
+    'spatialColumn' => 'wkt',
+    'mysqlVersion' => $GLOBALS['dbi']->getVersion()
 );
 $data = array(array('wkt' => $wkt_with_zero, 'srid' => $srid));
-$visualization = PMA_GIS_visualizationResults(
-    $data, $visualizationSettings, $format
-);
-$open_layers = PMA_GIS_visualizationResults($data, $visualizationSettings, 'ol');
+$visualization = GisVisualization::getByData($data, $visualizationSettings)
+    ->toImage('svg');
+
+$open_layers = GisVisualization::getByData($data, $visualizationSettings)
+    ->asOl();
 
 // If the call is to update the WKT and visualization make an AJAX response
-if (isset($_REQUEST['generate']) && $_REQUEST['generate'] == true) {
+if (isset($_POST['generate']) && $_POST['generate'] == true) {
     $extra_data = array(
         'result'        => $result,
         'visualization' => $visualization,
         'openLayers'    => $open_layers,
     );
-    $response = PMA_Response::getInstance();
+    $response = Response::getInstance();
     $response->addJSON($extra_data);
     exit;
 }
@@ -105,40 +114,41 @@ ob_start();
 
 echo '<form id="gis_data_editor_form" action="gis_data_editor.php" method="post">';
 echo '<input type="hidden" id="pmaThemeImage"'
-    . ' value="' . $GLOBALS['pmaThemeImage'] . '" />';
+    , ' value="' , $GLOBALS['pmaThemeImage'] , '" />';
 echo '<div id="gis_data_editor">';
 
 echo '<h3>';
 printf(
     __('Value for the column "%s"'),
-    htmlspecialchars($_REQUEST['field'])
+    htmlspecialchars($_POST['field'])
 );
 echo '</h3>';
 
 echo '<input type="hidden" name="field" value="'
-    . htmlspecialchars($_REQUEST['field']) . '" />';
+    , htmlspecialchars($_POST['field']) , '" />';
 // The input field to which the final result should be added
 // and corresponding null checkbox
-if (isset($_REQUEST['input_name'])) {
+if (isset($_POST['input_name'])) {
     echo '<input type="hidden" name="input_name" value="'
-        . htmlspecialchars($_REQUEST['input_name']) . '" />';
+        , htmlspecialchars($_POST['input_name']) , '" />';
 }
-echo PMA_URL_getHiddenInputs();
+echo Url::getHiddenInputs();
 
 echo '<!-- Visualization section -->';
-echo '<div id="placeholder" style="width:450px;height:300px;'
-    . ($srid != 0 ? 'display:none;' : '') . '">';
+echo '<div id="placeholder"'
+    , ($srid != 0 ? 'class="hide"' : '') , '>';
 echo $visualization;
 echo '</div>';
 
-echo '<div id="openlayersmap" style="width:450px;height:300px;'
-    . ($srid == 0 ? 'display:none;' : '') . '">';
+// No not remove inline style or it will cause "Cannot read property 'w' of null" on GIS editor map init
+echo '<div id="openlayersmap" style="width: ' . $visualizationSettings['width'] . 'px; height: ' . $visualizationSettings['height'] . 'px;" '
+    , ($srid == 0 ? 'class="hide"' : '') , '>';
 echo '</div>';
 
-echo '<div class="choice" style="float:right;clear:right;">';
+echo '<div class="choice floatright">';
 echo '<input type="checkbox" id="choice" value="useBaseLayer"'
-    . ($srid != 0 ? ' checked="checked"' : '') . '/>';
-echo '<label for="choice">' .  __("Use OpenStreetMaps as Base Layer") . '</label>';
+    , ($srid != 0 ? ' checked="checked"' : '') , '/>';
+echo '<label for="choice">' ,  __("Use OpenStreetMaps as Base Layer") , '</label>';
 echo '</div>';
 
 echo '<script language="javascript" type="text/javascript">';
@@ -151,17 +161,17 @@ echo '<!-- Header section - Inclueds GIS type selector and input field for SRID
 echo '<div id="gis_data_header">';
 echo '<select name="gis_data[gis_type]" class="gis_type">';
 foreach ($gis_types as $gis_type) {
-    echo '<option value="' . $gis_type . '"';
+    echo '<option value="' , $gis_type , '"';
     if ($geom_type == $gis_type) {
         echo ' selected="selected"';
     }
-    echo '>' . $gis_type . '</option>';
+    echo '>' , $gis_type , '</option>';
 }
 echo '</select>';
 echo '&nbsp;&nbsp;&nbsp;&nbsp;';
 /* l10n: Spatial Reference System Identifier */
-echo '<label for="srid">' .  __('SRID:') . '</label>';
-echo '<input name="gis_data[srid]" type="text" value="' . $srid . '" />';
+echo '<label for="srid">' ,  __('SRID:') , '</label>';
+echo '<input name="gis_data[srid]" type="text" value="' , $srid , '" />';
 echo '</div>';
 echo '<!-- End of header section -->';
 
@@ -171,32 +181,35 @@ echo '<div id="gis_data">';
 $geom_count = 1;
 if ($geom_type == 'GEOMETRYCOLLECTION') {
     $geom_count = (isset($gis_data[$geom_type]['geom_count']))
-        ? $gis_data[$geom_type]['geom_count'] : 1;
+        ? intval($gis_data[$geom_type]['geom_count']) : 1;
     if (isset($gis_data[$geom_type]['add_geom'])) {
         $geom_count++;
     }
     echo '<input type="hidden" name="gis_data[GEOMETRYCOLLECTION][geom_count]"'
-        . ' value="' . $geom_count . '" />';
+        , ' value="' , $geom_count , '" />';
 }
 
 for ($a = 0; $a < $geom_count; $a++) {
+    if (! isset($gis_data[$a])) {
+        continue;
+    }
 
     if ($geom_type == 'GEOMETRYCOLLECTION') {
         echo '<br/><br/>';
         printf(__('Geometry %d:'), $a + 1);
         echo '<br/>';
         if (isset($gis_data[$a]['gis_type'])) {
-            $type = $gis_data[$a]['gis_type'];
+            $type = htmlspecialchars($gis_data[$a]['gis_type']);
         } else {
             $type = $gis_types[0];
         }
-        echo '<select name="gis_data[' . $a . '][gis_type]" class="gis_type">';
+        echo '<select name="gis_data[' , $a , '][gis_type]" class="gis_type">';
         foreach (array_slice($gis_types, 0, 6) as $gis_type) {
-            echo '<option value="' . $gis_type . '"';
+            echo '<option value="' , $gis_type , '"';
             if ($type == $gis_type) {
                 echo ' selected="selected"';
             }
-            echo '>' . $gis_type . '</option>';
+            echo '>' , $gis_type , '</option>';
         }
         echo '</select>';
     } else {
@@ -206,16 +219,16 @@ for ($a = 0; $a < $geom_count; $a++) {
     if ($type == 'POINT') {
         echo '<br/>';
         echo __('Point:');
-        echo '<label for="x">' . __("X") . '</label>';
-        echo '<input name="gis_data[' . $a . '][POINT][x]" type="text"'
-            . ' value="' . escape($gis_data[$a]['POINT']['x']) . '" />';
-        echo '<label for="y">' . __("Y") . '</label>';
-        echo '<input name="gis_data[' . $a . '][POINT][y]" type="text"'
-            . ' value="' . escape($gis_data[$a]['POINT']['y']) . '" />';
+        echo '<label for="x">' , __("X") , '</label>';
+        echo '<input name="gis_data[' , $a , '][POINT][x]" type="text"'
+            , ' value="' , escape($gis_data[$a]['POINT']['x']) , '" />';
+        echo '<label for="y">' , __("Y") , '</label>';
+        echo '<input name="gis_data[' , $a , '][POINT][y]" type="text"'
+            , ' value="' , escape($gis_data[$a]['POINT']['y']) , '" />';
 
     } elseif ($type == 'MULTIPOINT' || $type == 'LINESTRING') {
         $no_of_points = isset($gis_data[$a][$type]['no_of_points'])
-            ? $gis_data[$a][$type]['no_of_points'] : 1;
+            ? intval($gis_data[$a][$type]['no_of_points']) : 1;
         if ($type == 'LINESTRING' && $no_of_points < 2) {
             $no_of_points = 2;
         }
@@ -226,37 +239,37 @@ for ($a = 0; $a < $geom_count; $a++) {
         if (isset($gis_data[$a][$type]['add_point'])) {
             $no_of_points++;
         }
-        echo '<input type="hidden" value="' . $no_of_points . '"'
-            . ' name="gis_data[' . $a . '][' . $type . '][no_of_points]" />';
+        echo '<input type="hidden" value="' , $no_of_points , '"'
+            , ' name="gis_data[' , $a , '][' , $type , '][no_of_points]" />';
 
         for ($i = 0; $i < $no_of_points; $i++) {
             echo '<br/>';
             printf(__('Point %d'), $i + 1);
             echo ': ';
-            echo '<label for="x">' .  __("X") . '</label>';
+            echo '<label for="x">' ,  __("X") , '</label>';
             echo '<input type="text"'
-                . ' name="gis_data[' . $a . '][' . $type . '][' . $i . '][x]"'
-                . ' value="' . escape($gis_data[$a][$type][$i]['x']) . '" />';
-            echo '<label for="y">' . __("Y") . '</label>';
+                , ' name="gis_data[' , $a , '][' , $type , '][' , $i , '][x]"'
+                , ' value="' , escape($gis_data[$a][$type][$i]['x']) , '" />';
+            echo '<label for="y">' , __("Y") , '</label>';
             echo '<input type="text"'
-                . ' name="gis_data[' . $a . '][' . $type . '][' . $i . '][y]"'
-                . ' value="' . escape($gis_data[$a][$type][$i]['y']). '" />';
+                , ' name="gis_data[' , $a , '][' , $type , '][' , $i , '][y]"'
+                , ' value="' , escape($gis_data[$a][$type][$i]['y']) , '" />';
         }
         echo '<input type="submit"'
-            . ' name="gis_data[' . $a . '][' . $type . '][add_point]"'
-            . ' class="add addPoint" value="' . __("Add a point") . '" />';
+            , ' name="gis_data[' , $a , '][' , $type , '][add_point]"'
+            , ' class="add addPoint" value="' , __("Add a point") , '" />';
 
     } elseif ($type == 'MULTILINESTRING' || $type == 'POLYGON') {
         $no_of_lines = isset($gis_data[$a][$type]['no_of_lines'])
-            ? $gis_data[$a][$type]['no_of_lines'] : 1;
+            ? intval($gis_data[$a][$type]['no_of_lines']) : 1;
         if ($no_of_lines < 1) {
             $no_of_lines = 1;
         }
         if (isset($gis_data[$a][$type]['add_line'])) {
             $no_of_lines++;
         }
-        echo '<input type="hidden" value="' . $no_of_lines . '"'
-            . ' name="gis_data[' . $a . '][' . $type . '][no_of_lines]" />';
+        echo '<input type="hidden" value="' , $no_of_lines , '"'
+            , ' name="gis_data[' , $a , '][' , $type , '][no_of_lines]" />';
 
         for ($i = 0; $i < $no_of_lines; $i++) {
             echo '<br/>';
@@ -271,7 +284,7 @@ for ($a = 0; $a < $geom_count; $a++) {
             }
 
             $no_of_points = isset($gis_data[$a][$type][$i]['no_of_points'])
-                ? $gis_data[$a][$type][$i]['no_of_points'] : 2;
+                ? intval($gis_data[$a][$type][$i]['no_of_points']) : 2;
             if ($type == 'MULTILINESTRING' && $no_of_points < 2) {
                 $no_of_points = 2;
             }
@@ -281,37 +294,38 @@ for ($a = 0; $a < $geom_count; $a++) {
             if (isset($gis_data[$a][$type][$i]['add_point'])) {
                 $no_of_points++;
             }
-            echo '<input type="hidden" value="' . $no_of_points . '"'
-               . ' name="gis_data[' . $a . '][' . $type . '][' . $i . '][no_of_points]" />';
+            echo '<input type="hidden" value="' , $no_of_points , '"'
+                , ' name="gis_data[' , $a , '][' , $type , '][' , $i
+                , '][no_of_points]" />';
 
             for ($j = 0; $j < $no_of_points; $j++) {
                 echo('<br/>');
                 printf(__('Point %d'), $j + 1);
                 echo ': ';
-                echo '<label for="x">' .  __("X") . '</label>';
-                echo '<input type="text"'
-                    . ' name="gis_data[' . $a . '][' . $type . '][' . $i . '][' . $j . '][x]"'
-                    . ' value="' . escape($gis_data[$a][$type][$i][$j]['x']) . '" />';
-                echo '<label for="y">' . __("Y") . '</label>';
-                echo '<input type="text"'
-                    . ' name="gis_data[' . $a . '][' . $type . '][' . $i . '][' . $j . '][y]"'
-                    . ' value="' . escape($gis_data[$a][$type][$i][$j]['x']) . '" />';
+                echo '<label for="x">' ,  __("X") , '</label>';
+                echo '<input type="text" name="gis_data[' , $a , '][' , $type . ']['
+                    , $i , '][' , $j , '][x]" value="'
+                    , escape($gis_data[$a][$type][$i][$j]['x']) , '" />';
+                echo '<label for="y">' , __("Y") , '</label>';
+                echo '<input type="text" name="gis_data[' , $a , '][' , $type , ']['
+                    , $i , '][' , $j , '][y]"' , ' value="'
+                    , escape($gis_data[$a][$type][$i][$j]['y']) , '" />';
             }
-            echo '<input type="submit"'
-                . ' name="gis_data[' . $a . '][' . $type . '][' . $i . '][add_point]"'
-                . ' class="add addPoint" value="' . __("Add a point") . '" />';
+            echo '<input type="submit" name="gis_data[' , $a , '][' , $type , ']['
+                , $i , '][add_point]"'
+                , ' class="add addPoint" value="' , __("Add a point") , '" />';
         }
         $caption = ($type == 'MULTILINESTRING')
             ? __('Add a linestring')
             : __('Add an inner ring');
         echo '<br/>';
         echo '<input type="submit"'
-            . ' name="gis_data[' . $a . '][' . $type . '][add_line]"'
-            . ' class="add addLine" value="' . $caption . '" />';
+            , ' name="gis_data[' , $a , '][' , $type , '][add_line]"'
+            , ' class="add addLine" value="' , $caption , '" />';
 
     } elseif ($type == 'MULTIPOLYGON') {
         $no_of_polygons = isset($gis_data[$a][$type]['no_of_polygons'])
-            ? $gis_data[$a][$type]['no_of_polygons'] : 1;
+            ? intval($gis_data[$a][$type]['no_of_polygons']) : 1;
         if ($no_of_polygons < 1) {
             $no_of_polygons = 1;
         }
@@ -319,14 +333,14 @@ for ($a = 0; $a < $geom_count; $a++) {
             $no_of_polygons++;
         }
         echo '<input type="hidden"'
-            . ' name="gis_data[' . $a . '][' . $type . '][no_of_polygons]"'
-            . ' value="' . $no_of_polygons . '" />';
+            , ' name="gis_data[' , $a , '][' , $type , '][no_of_polygons]"'
+            , ' value="' , $no_of_polygons , '" />';
 
         for ($k = 0; $k < $no_of_polygons; $k++) {
             echo '<br/>';
             printf(__('Polygon %d:'), $k + 1);
             $no_of_lines = isset($gis_data[$a][$type][$k]['no_of_lines'])
-                ? $gis_data[$a][$type][$k]['no_of_lines'] : 1;
+                ? intval($gis_data[$a][$type][$k]['no_of_lines']) : 1;
             if ($no_of_lines < 1) {
                 $no_of_lines = 1;
             }
@@ -334,8 +348,8 @@ for ($a = 0; $a < $geom_count; $a++) {
                 $no_of_lines++;
             }
             echo '<input type="hidden"'
-                . ' name="gis_data[' . $a . '][' . $type . '][' . $k . '][no_of_lines]"'
-                . ' value="' . $no_of_lines . '" />';
+                , ' name="gis_data[' , $a , '][' , $type , '][' , $k
+                , '][no_of_lines]"' , ' value="' , $no_of_lines , '" />';
 
             for ($i = 0; $i < $no_of_lines; $i++) {
                 echo '<br/><br/>';
@@ -346,7 +360,7 @@ for ($a = 0; $a < $geom_count; $a++) {
                 }
 
                 $no_of_points = isset($gis_data[$a][$type][$k][$i]['no_of_points'])
-                    ? $gis_data[$a][$type][$k][$i]['no_of_points'] : 4;
+                    ? intval($gis_data[$a][$type][$k][$i]['no_of_points']) : 4;
                 if ($no_of_points < 4) {
                     $no_of_points = 4;
                 }
@@ -354,65 +368,69 @@ for ($a = 0; $a < $geom_count; $a++) {
                     $no_of_points++;
                 }
                 echo '<input type="hidden"'
-                    . ' name="gis_data[' . $a . '][' . $type . '][' . $k . '][' . $i . '][no_of_points]"'
-                    . ' value="' . $no_of_points . '" />';
+                    , ' name="gis_data[' , $a , '][' , $type , '][' , $k , '][' , $i
+                    , '][no_of_points]"' , ' value="' , $no_of_points , '" />';
 
                 for ($j = 0; $j < $no_of_points; $j++) {
                     echo '<br/>';
                     printf(__('Point %d'), $j + 1);
                     echo ': ';
-                    echo '<label for="x">' .  __("X") . '</label>';
+                    echo '<label for="x">' ,  __("X") , '</label>';
                     echo '<input type="text"'
-                        . ' name="gis_data[' . $a . '][' . $type . '][' . $k . '][' . $i . '][' . $j . '][x]"'
-                        . ' value="' . escape($gis_data[$a][$type][$k][$i][$j]['x']). '" />';
-                    echo '<label for="y">' . __("Y") . '</label>';
+                        , ' name="gis_data[' , $a , '][' , $type , '][' , $k , ']['
+                        , $i , '][' , $j , '][x]"'
+                        , ' value="' , escape($gis_data[$a][$type][$k][$i][$j]['x'])
+                        , '" />';
+                    echo '<label for="y">' , __("Y") , '</label>';
                     echo '<input type="text"'
-                        . ' name="gis_data[' . $a . '][' . $type . '][' . $k . '][' . $i . '][' . $j . '][y]"'
-                        . ' value="' . escape($gis_data[$a][$type][$k][$i][$j]['y']) . '" />';
+                        , ' name="gis_data[' , $a , '][' , $type , '][' , $k , ']['
+                        , $i , '][' , $j , '][y]"'
+                        , ' value="' , escape($gis_data[$a][$type][$k][$i][$j]['y'])
+                        , '" />';
                 }
                 echo '<input type="submit"'
-                    . ' name="gis_data[' . $a . '][' . $type . '][' . $k . '][' . $i . '][add_point]"'
-                    . ' class="add addPoint" value="' . __("Add a point") . '" />';
+                    , ' name="gis_data[' , $a , '][' , $type , '][' , $k , '][' , $i
+                    , '][add_point]"'
+                    , ' class="add addPoint" value="' , __("Add a point") , '" />';
             }
             echo '<br/>';
             echo '<input type="submit"'
-                . ' name="gis_data[' . $a . '][' . $type . '][' . $k . '][add_line]"'
-                . ' class="add addLine" value="' . __('Add an inner ring'). '" />';
+                , ' name="gis_data[' , $a , '][' , $type , '][' , $k , '][add_line]"'
+                , ' class="add addLine" value="' , __('Add an inner ring') , '" />';
             echo '<br/>';
         }
         echo '<br/>';
         echo '<input type="submit"'
-            . ' name="gis_data[' . $a . '][' . $type . '][add_polygon]"'
-            . ' class="add addPolygon" value="' .  __('Add a polygon') . '" />';
+            , ' name="gis_data[' , $a , '][' , $type , '][add_polygon]"'
+            , ' class="add addPolygon" value="' ,  __('Add a polygon') , '" />';
     }
 }
 if ($geom_type == 'GEOMETRYCOLLECTION') {
     echo '<br/><br/>';
     echo '<input type="submit" name="gis_data[GEOMETRYCOLLECTION][add_geom]"'
-        . 'class="add addGeom" value="' . __("Add geometry") . '" />';
+        , 'class="add addGeom" value="' , __("Add geometry") , '" />';
 }
 echo '</div>';
 echo '<!-- End of data section -->';
 
 echo '<br/>';
-echo '<input type="submit" name="gis_data[save]" value="' . __('Go') . '" />';
+echo '<input type="submit" name="gis_data[save]" value="' , __('Go') , '" />';
 
 echo '<div id="gis_data_output">';
-echo '<h3>' . __('Output') . '</h3>';
+echo '<h3>' , __('Output') , '</h3>';
 echo '<p>';
 echo __(
-    'Choose "GeomFromText" from the "Function" column and paste the'
-    . ' string below into the "Value" field'
+    'Choose "ST_GeomFromText" from the "Function" column and paste the'
+    . ' string below into the "Value" field.'
 );
 echo '</p>';
 echo '<textarea id="gis_data_textarea" cols="95" rows="5">';
-echo $result;
+echo htmlspecialchars($result);
 echo '</textarea>';
 echo '</div>';
 
 echo '</div>';
 echo '</form>';
 
-PMA_Response::getInstance()->addJSON('gis_editor', ob_get_contents());
+Response::getInstance()->addJSON('gis_editor', ob_get_contents());
 ob_end_clean();
-?>
