@@ -224,6 +224,10 @@ input[type=number] {
     width: 50px;
 }
 
+input#auto_increment_opt {
+    width: min-content;
+}
+
 input[type=text],
 input[type=password],
 input[type=number],
@@ -902,9 +906,10 @@ body#loginform div.container {
 }
 
 form.login label {
-    float: <?php echo $left; ?>;
     width: 10em;
     font-weight: bolder;
+    display: inline-block;
+    margin-<?php echo $left; ?>: 2em;
 }
 
 form.login input[type=text],
@@ -956,6 +961,9 @@ form.login select {
     display: inline-block;
 }
 
+li.last.database{
+    margin-bottom: 15px !important;
+}
 /******************************************************************************/
 /* specific elements */
 
@@ -2710,6 +2718,7 @@ fieldset .disabled-field td {
 }
 
 .pma_table th.draggable span,
+.sticky_columns th.draggable span,
 .pma_table tbody td span {
     display: block;
     overflow: hidden;
@@ -2987,6 +2996,10 @@ body .ui-widget {
     font-size: 1em;
 }
 
+body #ui-datepicker-div {
+    z-index: 9999 !important;
+}
+
 .ui-dialog fieldset legend a {
     color: #235A81;
 }
